Guides
------------------------

.. toctree::
   :maxdepth: 2

   transforms
   flax_gspmd
   filters_guide
   randomness
   performance
   linen_to_nnx
   bridge_guide
   surgery
   checkpointing
   jax_and_nnx_transforms
   haiku_to_flax
   gemma
